# Generated by roxygen2: do not edit by hand

S3method(print,mb_assumption_register)
S3method(print,mb_balance_table)
S3method(print,mb_cea)
S3method(print,mb_ceac)
S3method(print,mb_cmo)
S3method(print,mb_confidence)
S3method(print,mb_confidence_summary)
S3method(print,mb_contribution_claim)
S3method(print,mb_counterfactual)
S3method(print,mb_did)
S3method(print,mb_event_study)
S3method(print,mb_icer)
S3method(print,mb_its)
S3method(print,mb_logframe)
S3method(print,mb_plan)
S3method(print,mb_questions)
S3method(print,mb_report)
S3method(print,mb_sms_rating)
S3method(print,mb_stakeholders)
S3method(print,mb_toc)
S3method(summary,mb_did)
export(mb_assumptions)
export(mb_balance_table)
export(mb_cea)
export(mb_ceac)
export(mb_cluster_design)
export(mb_cmo)
export(mb_confidence)
export(mb_confidence_summary)
export(mb_contribution_claim)
export(mb_counterfactual)
export(mb_daly)
export(mb_data_versions)
export(mb_did_2x2)
export(mb_evaluation_plan)
export(mb_evaluation_report)
export(mb_event_study)
export(mb_icc_reference)
export(mb_icer)
export(mb_inb)
export(mb_its)
export(mb_logframe)
export(mb_mde)
export(mb_power)
export(mb_qaly)
export(mb_questions)
export(mb_sample_size)
export(mb_schedule_table)
export(mb_sms_explain)
export(mb_sms_rate)
export(mb_stakeholders)
export(mb_stepped_wedge)
export(mb_theory_of_change)
export(mb_to_excel)
export(mb_to_latex)
export(mb_to_word)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_bullets)
importFrom(cli,cli_h1)
importFrom(cli,cli_h2)
importFrom(cli,cli_inform)
importFrom(cli,cli_text)
importFrom(cli,cli_warn)
importFrom(stats,model.matrix)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
